@@ -1,3 +1,5 @@
+# coding=utf-8
+"""Common helpers to bootstrap fabric."""
 import os
 from fabric.api import env, task, fastprint, run, hide
 from fabric.utils import _AttributeDict as fdict
@@ -37,7 +39,11 @@ def setup_env():
     env.fg = fdict()
     with hide('output'):
         env.fg.user = run('whoami')
-        env.fg.hostname = fabtools.system.get_hostname()
+        # Workaround for
+        env.fg.hostname = run('hostname')
+        # this which fails in docker - see
+        # https://github.com/dotcloud/docker/issues/1301
+        #env.fg.hostname = fabtools.system.get_hostname()
         env.fg.home = os.path.join('/home/', env.fg.user)
         env.fg.workspace = os.path.join(env.fg.home, 'dev')
         env.fg.inasafe_git_url = 'git://github.com/AIFDR/inasafe.git'
@@ -58,6 +64,7 @@ def setup_env():
 def add_ubuntugis_ppa():
     """Ensure we have ubuntu-gis repo."""
     fabtools.deb.update_index(quiet=True)
+    fabtools.require.deb.package('software-properties-common')
     fabtools.require.deb.ppa(
         #'ppa:ubuntugis/ubuntugis-unstable', auto_yes=True)
         'ppa:ubuntugis/ubuntugis-unstable')
